@@ -6,12 +6,12 @@ __all__ = [
     "GraphQL",
     "MeasurementScalar",
     "MeasurementType",
-    "graphQlMutation",
-    "graphQlProperty",
+    "graph_ql_mutation",
+    "graph_ql_property",
 ]
 
 from general_manager.api.graphql import GraphQL
 from general_manager.api.graphql import MeasurementScalar
 from general_manager.api.graphql import MeasurementType
-from general_manager.api.mutation import graphQlMutation
-from general_manager.api.property import graphQlProperty
+from general_manager.api.mutation import graph_ql_mutation
+from general_manager.api.property import graph_ql_property
