@@ -5,6 +5,7 @@ from __future__ import annotations
 __all__ = [
     "CalculationInterface",
     "DatabaseInterface",
+    "ExistingModelInterface",
     "GeneralManager",
     "GraphQL",
     "Input",
@@ -14,10 +15,13 @@ __all__ = [
     "get_logger",
     "graph_ql_mutation",
     "graph_ql_property",
+    "permission_functions",
+    "register_permission",
 ]
 
 from general_manager.interface.calculation_interface import CalculationInterface
 from general_manager.interface.database_interface import DatabaseInterface
+from general_manager.interface.existing_model_interface import ExistingModelInterface
 from general_manager.manager.general_manager import GeneralManager
 from general_manager.api.graphql import GraphQL
 from general_manager.manager.input import Input
@@ -27,3 +31,5 @@ from general_manager.rule.rule import Rule
 from general_manager.logging import get_logger
 from general_manager.api.mutation import graph_ql_mutation
 from general_manager.api.property import graph_ql_property
+from general_manager.permission.permission_checks import permission_functions
+from general_manager.permission.permission_checks import register_permission
