@@ -6,6 +6,7 @@ __all__ = [
     "CalculationInterface",
     "DBBasedInterface",
     "DatabaseInterface",
+    "ExistingModelInterface",
     "InterfaceBase",
     "ReadOnlyInterface",
 ]
@@ -13,5 +14,6 @@ __all__ = [
 from general_manager.interface.calculation_interface import CalculationInterface
 from general_manager.interface.database_based_interface import DBBasedInterface
 from general_manager.interface.database_interface import DatabaseInterface
+from general_manager.interface.existing_model_interface import ExistingModelInterface
 from general_manager.interface.base_interface import InterfaceBase
 from general_manager.interface.read_only_interface import ReadOnlyInterface
